@@ -63,7 +63,10 @@ void BacklightHelper::init()
 
     m_anim.setEasingCurve(QEasingCurve::InOutQuad);
     connect(&m_anim, &QVariantAnimation::valueChanged, this, [this](const QVariant &value) {
-        writeBrightness(value.toInt());
+        // When animating to zero, it emits a value change to 0 before starting the animation...
+        if (m_anim.state() == QAbstractAnimation::Running) {
+            writeBrightness(value.toInt());
+        }
     });
 
     m_isSupported = true;
